using System;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.LiveConsultation;
using WingInterfaceLibrary.LiveConsultation.Enums;

namespace WingInterfaceLibrary.DTO.Consultation
{
    /// <summary>
    /// 会诊详情信息
    /// </summary>
    public class ConsultationDetailDTO
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 申请机构编码
        /// </summary>
        /// <value>OrganizationDO_123456789</value>
        public string ApplyOrganizationCode { get; set; } = string.Empty;

        /// <summary>
        /// 申请科室编码
        /// </summary>
        /// <value>OrganizationDO_123456789</value>
        public string ApplyDepartmentCode { get; set; } = string.Empty;

        /// <summary>
        /// 申请医生编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string ApplyUserCode { get; set; } = string.Empty;

        /// <summary>
        /// 会诊医院编码
        /// </summary>
        /// <value>OrganizationDO_123456789</value>
        public string ExpertOrganizationCode { get; set; } = string.Empty;

        /// <summary>
        /// 会诊科室编码
        /// </summary>
        /// <value>OrganizationDO_123456789</value>
        public string ExpertDepartmentCode { get; set; } = string.Empty;

        /// <summary>
        /// 会诊专家编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string ExpertUserCode { get; set; } = string.Empty;

        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>DeviceDO_123456789</value>
        public string DeviceCode { get; set; } = string.Empty;

        /// <summary>
        /// 操作医生编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string OperateUserCode { get; set; } = string.Empty;

        /// <summary>
        /// 扫查医生编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string ScanUserCode { get; set; } = string.Empty;

        /// <summary>
        /// 病人编码
        /// </summary>
        public string PatientCode { get; set; }

        /// <summary>
        /// 服务对象
        /// </summary>
        /// <value>1</value>
        public OrganizationPatientTypeEnum PatientType { get; set; } = OrganizationPatientTypeEnum.Person;

        /// <summary>
        /// 检查部位：肝脏；胆囊；胎儿
        /// </summary>
        /// <value>0</value>
        public string ScanPosition { get; set; }

        /// <summary>
        /// 会诊申请时间
        /// </summary>
        /// <value>2022-09-29 10:00:00</value>
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 会诊时间
        /// </summary>
        /// <value>2022-09-30 14:00:00</value>
        public DateTime ConsultationTime { get; set; }

        /// <summary>
        /// 会诊状态
        /// </summary>
        /// <value>1</value>
        public ConsultationStatusEnum ConsultationStatus { get; set; } = ConsultationStatusEnum.Applied;

        /// <summary>
        /// 申请医院名称
        /// </summary>
        /// <value>申请医院</value>
        public string ApplyOrganizationName { get; set; } = string.Empty;

        /// <summary>
        /// 申请医生名称
        /// </summary>
        /// <value>刘医师/value>
        public string ApplyUserName { get; set; } = string.Empty;

        /// <summary>
        /// 操作医生名称
        /// </summary>
        /// <value>刘医师/value>
        public string OperateUserName { get; set; } = string.Empty;

        /// <summary>
        /// 扫查医生姓名
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string ScanUserName { get; set; } = string.Empty;

        /// <summary>
        /// 会诊医院名称
        /// </summary>
        /// <value>上级医院</value>
        public string ExpertOrganizationName { get; set; } = string.Empty;

        /// <summary>
        /// 会诊专家名称
        /// </summary>
        /// <value>菲儿</value>
        public string ExpertUserName { get; set; } = string.Empty;

        /// <summary>
        /// 会诊设备名称
        /// </summary>
        /// <value></value>
        public string DeviceName{get;set;}=string.Empty;

        /// <summary>
        /// 患者姓名
        /// </summary>
        /// <value>	马丽</value>
        public string PatientName { get; set; } = string.Empty;

        /// <summary>
        /// 患者性别
        /// </summary>
        /// <value>Female</value>
        public string Sex { get; set; } = "Female";

        /// <summary>
        /// 病人信息
        /// </summary>
        /// <value></value>
        public List<DataItemDTO> PatientDatas { get; set; } = new List<DataItemDTO>();

        /// <summary>
        /// 会诊中保存的文件信息集合
        /// </summary>
        /// <returns></returns>
        public List<ConsultationFileDTO> FileInfos { get; set; } = new List<ConsultationFileDTO>();

        /// <summary>
        /// 拒绝申请会诊原因
        /// </summary>
        /// <value></value>
        public string RejectReason { get; set; } = string.Empty;

        /// <summary>
        /// 地点
        /// </summary>
        /// <value></value>
        public string Location { get; set; }

        /// <summary>
        /// 会诊参与方对象列表
        /// </summary>
        /// <value></value>
        public List<ConsultationMemberDTO>  ConsultationMembers { get; set; }

        /// <summary>
        /// 会诊描述
        /// </summary>
        /// <value></value>
        public string Description { get; set; }

        /// <summary>
        /// 会诊提醒集合
        /// </summary>
        /// <value></value>
        public List<ConsultationReminderDTO> ConsultationReminders { get; set; }

        /// <summary>
        /// 审核人编码
        /// </summary>
        /// <value></value>
        public string ApproverCode { get; set; }

        /// <summary>
        /// 报告方式
        /// </summary>
        /// <value></value>
        public ConsultationReportMode ReportMode { get; set; }
        
        /// <summary>
        /// 疾病名称
        /// </summary>
        /// <value></value>
        public string Diseases { get; set; }

        /// <summary>
        /// 初步诊断
        /// </summary>
        /// <value>初步诊断结论</value>   
        public string PrimaryDiagnosis { get; set; } = string.Empty;
    }

    /// <summary>
    /// 参与成员对象
    /// </summary>
    public class ConsultationMemberDTO
    {
        /// <summary>
        /// 参与人员编码
        /// </summary>
        /// <value></value>
        public string MemberCode { get; set; }

        /// <summary>
        /// 参与人员机构编码
        /// </summary>
        /// <value></value>
        public string MemberOrganizationCode { get; set; }

        /// <summary>
        /// 参与人员科室编码
        /// </summary>
        /// <value></value>
        public string MemberDepartmentCode { get; set; }

        /// <summary>
        /// 参与人员状态
        /// </summary>
        /// <value></value>
        public LiveConsultationMemberStatus MemberStatus { get; set; }

        /// <summary>
        /// 参与人员操作时间
        /// </summary>
        /// <value></value>
        public DateTime MemberOperateTime { get; set; }
    }
}