﻿using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Management;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Request.Management;
using WingInterfaceLibrary.DTO.ReportTemplate;
using WingInterfaceLibrary.DTO.User;
using WingInterfaceLibrary.Result.Management;
using WingInterfaceLibrary.DTO.CMSStatistic;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    public partial interface IAdminDBService
    {
        Task<string> InsertAdminAsync(CreateAdminDBRequest request);
        Task<AdminInfoDTO> FindAdminByNameAsync(string name);
        /// <summary>模糊查询管理员集合</summary>
        /// <param name="name"></param>
        /// <returns></returns>
        Task<List<AdminInfoDTO>> FindAdminsByNameAsync(string name);
        Task<AdminInfoDTO> FindAdminByCodeAsync(string code);
        Task<PageResult<AdminInfoDTO>> FindAdminPagesAsync(GetAdminPagesRequest request);
        Task<bool> DeleteAdminByCodeAsync(string code);
        Task<bool> UpdateAdminByCodeAsync(string code, AdminInfoDTO data, string extensionData);
        Task<List<AdminInfoDTO>> FindAdminListByRoleCodeAsync(string roleCode);

        Task<List<AdminInfoDTO>> FindAdminListByRoleCodesAsync(List<string> roleCodes);

        /// <summary>
        /// 根据管理员编码列表获取所有管理员信息
        /// </summary>
        /// <param name="adminCodes">管理员编码列表</param>
        /// <returns>是否成功</returns>  
        Task<List<AdminInfoDTO>> FindAdminListByAdminCodesAsync(List<string> adminCodes);

        /// <summary>
        /// 修改管理员密码
        /// </summary>
        /// <param name="code">管理员code</param>
        /// <param name="entity">管理员实体</param>
        /// <returns></returns>
        Task<bool> ModifyAdminPasswordAsync(string code, AdminInfoDTO entity);
        
        /// <summary>
        /// 更新管理员锁定次数
        /// </summary>
        /// <param name="code"></param>
        /// <param name="loginLockInfoDTO"></param>
        /// <returns></returns>
        Task<bool> UpdateAdminLoginLockInfoAsync(string code, LoginLockInfoDTO  loginLockInfoDTO);

        /// <summary>
        /// 查询CMS Json模板接口
        /// </summary>
        /// <param name="request">token请求实体</param>
        /// <returns></returns>
        Task<CMSTemplateResult> FindCMSTemplateDetailDBAsync(FindCMSTemplateDetailDBRequest request);

        /// <summary>
        /// 查询CMS统计接口
        /// </summary>
        /// <param name="request">token请求实体</param>
        /// <returns></returns>
        Task<IList<CMSStatisticRecordDTO>> FindCMSStatisticRecordsDBAsync(FindCMSStatisticDBRequest request);

        /// <summary>
        /// 查找CMS模版分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<CMSTemplateResult>> FindCMSTemplatePageDBAsync(FindCMSTemplatePageDBRequest request);
    }
}
