using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.DTO.CMSStatistic;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Request;


namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// CMS模板服务
    /// </summary>
    public interface ICMSTemplateDBService
    {
        /// <summary>
        /// 获取Banner设置列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<BannerSettingDTO>> GetBannerSettingDBAsync(GetBannerSettingDBRequest request);

        /// <summary>
        /// 增加Banner设置信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddBannerSettingDBAsync(AddBannerSettingDBRequest request);

        /// <summary>
        /// 更新 Banner设置信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateBannerSettingDBAsync(UpdateBannerSettingDBRequest request);

        /// <summary>
        /// 删除 Banner
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteBannerSettingDBAsync(string bannerSettingCode);

        /// <summary>
        /// 通过code 获取Banner设置
        /// </summary>
        /// <returns></returns>
        Task<BannerSettingDTO> GetBannerSettingDBByCodeAsync(string code);
        
        /// <summary>
        /// 获取CMS模板列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<CMSTemplateDTO>> GetCMSTemplatesDBAsync(GetCMSTemplatesDBRequest request);

        /// <summary>
        /// 模板名称获取模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<CMSTemplateDTO> GetCMSTemplateDBByNameDBAsync(string  name);

        /// <summary>
        /// 增加CMS模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddCMSTemplatesDBAsync(AddCMSTemplatesDBRequest request);

        /// <summary>
        /// 更新CMS模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCMSTemplatesDBAsync(UpdateCMSTemplatesDBRequest request);

        /// <summary>
        /// 删除CMS模板请求
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteCMSTemplatesDBAsync(string code);

        /// <summary>
        /// 通过codes 获取CMS模板列表
        /// </summary>
        /// <returns></returns>
        Task<CMSTemplateDTO> GetCMSTemplateDBByCodeAsync(string  code);

        /// <summary>
        /// 增加公告内容接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddAnnouncementDBAsync(AddAnnouncementDBRequest request);

        /// <summary>
        /// 根据用户Code获取公告内容列表接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<AnnouncementInfoDTO>> GetAnnouncementsDBByUserCodeAsync(GetAnnouncementsDBByUserCodeRequest request);

        /// <summary>
        /// 根据公告Code获取内容接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<AnnouncementInfoDTO> GetAnnouncementDBByCodeAsync(GetAnnouncementDBByCodeRequest request);

        /// <summary>
        /// 获取公告内容接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<IList<AnnouncementInfoDTO>> GetAnnouncementsDBAsync(GetAnnouncementsDBRequest request);

        /// <summary>
        /// 删除公告内容接口
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteAnnouncementDBByCodeAsync(string code);

        /// <summary>
        /// 删除消息接口
        /// </summary>
        /// <returns></returns>
        Task<bool> DeleteStatisticMessagesDBByCodeAsync(string code);

        /// <summary>
        /// 通过UserCode获取消息列表接口
        /// </summary>
        /// <returns></returns>
        Task<PageCollection<StatisticMessageInfoDTO>> GetStatisticMessagesPageDBByUserCodeAsync(GetStatisticMessagesDBByUserCodePageRequest request);

        /// <summary>
        /// 增加消息列表接口
        /// </summary>
        /// <returns></returns>
        Task<bool> AddStatisticMessagesDBAsync(AddStatisticMessagesDBRequest request);

        /// <summary>
        ///更新消息信息接口
        /// </summary>
        /// <returns></returns>
        Task<bool> UpdateStatisticMessagesDBAsync(UpdateStatisticMessagesDBRequest request);

        /// <summary>
        ///批量更新消息状态信息列表接口
        /// </summary>
        /// <returns></returns>
        Task<bool> UpdateStatisticMessagesStatusDBAsync(UpdateStatisticMessagesStatusDBequest request);
    }
}