using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Consultation;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 会诊记录DB接口
    /// </summary>
    public interface IConsultationRecordDBService
    {
        /// <summary>
        /// 新增会诊记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> InsertConsultationRecordAsync(CreateConsultationRecordDBRequest request);
        /// <summary>
        /// 查询会诊记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ConsultationDetailDTO> FindConsultationRecordByCodeAsync(ConsultationRecordCodeDBRequest request);
        /// <summary>
        /// 查询会诊记录分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ConsultationDetailDTO>> FindConsultationRecordPagesAsync(GetConsultationRecordPagesDBRequest request);
        /// <summary>
        /// 删除会诊记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteConsultationRecordByCodeAsync(ConsultationRecordCodeDBRequest request);
        /// <summary>
        /// 更新会诊记录
        /// </summary>
        /// <param name="data"></param>
        /// <param name="canNull"></param>
        /// <returns></returns>
        Task<bool> UpdateConsultationRecordAsync(ConsultationDetailDTO data, bool canNull = false); 

        /// <summary>
        /// 添加随访信息
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> AddFollowUpVisitInfoAsync(AddFollowUpVisitInfoDBRequest request);

        /// <summary>
        /// 删除随访信息
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> DeleteFollowUpVisitInfoAsync(DeleteFollowUpVisitInfoDBRequest request);

        /// <summary>
        /// 修改随访信息
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> UpdateFollowUpVisitInfoAsync(UpdateFollowUpVisitInfoDBRequest request);

        /// <summary>
        /// 查询随访信息
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<List<FollowUpVisitDTO>> GetFollowUpVisitInfoAsync(GetFollowUpVisitInfoDBRequest request);

        /// <summary>
        /// 查询随访信息详情
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<FollowUpVisitDTO> GetFollowUpVisitInfoDetailAsync(GetFollowUpVisitInfoDetailDBRequest request);

        /// <summary>
        /// 设置需要随访
        /// </summary>
        /// <returns></returns>
        Task<bool> SetNeedFollowUpVisitAsync(SetNeedFollowUpVisitDBRequest request);

        /// <summary>
        /// 新增会诊评价
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> AddConsultationEvaluateAsync(AddConsultationEvaluateDBRequest request);

        /// <summary>
        /// 删除会诊评价
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> DeleteConsultationEvaluateAsync(DeleteConsultationEvaluateDBRequest request);

        /// <summary>
        /// 修改会诊评价
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<bool> UpdateConsultationEvaluateAsync(UpdateConsultationEvaluateDBRequest request);

        /// <summary>
        /// 查询会诊评价详情
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<ConsultationEvaluateDTO> GetConsultationEvaluateDetailAsync(GetConsultationEvaluateDBRequest request);

        /// <summary>
        /// 设置会诊参与人信息
        /// </summary>
        /// <returns></returns>
        Task<bool> SetMemberStatusAsync(SetMemberStatusDBRequest request);
    }
}