﻿using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.Request.Notification;
using WingInterfaceLibrary.Notifications;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 通知消息服务
    /// </summary>
    /// <docFirstDirectory>推送通知服务</docFirstDirectory>
    /// <docSecondDirectory>推送通知</docSecondDirectory>
    public interface INotificationService
    {
        /// <summary>
        /// 发送通知,等待发送完消息返回是否成功
        /// </summary>
        /// <param name="request">发送通知请求</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        Task<bool> SendMessageAsync(SendNotificationRequest request);

        /// <summary>
        /// 发送通知,消息进入发送队列，返回是否成功进入发送队列
        /// </summary>
        /// <param name="request">发送通知请求</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        Task<bool> PostMessageAsync(SendNotificationRequest request);

        /// <summary>
        /// 群发通知，消息进入发送队列，返回是否成功进入发送队列
        /// </summary>
        /// <param name="request">群发通知请求</param>
        /// <returns>是否成功</returns>
        Task<bool> BroadcastMessageAsync(BroadcastNotificationRequest request);

        /// <summary>
        /// 申请独立队列
        /// </summary>
        /// <param name="request"></param>
        /// <returns>队列标识</returns>
        Task<string> OpenNotifyQueueAsync(OpenNotifyQueueRequest request);

        /// <summary>
        /// 释放队列
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CloseNotifyQueueAsync(CloseNotifyQueueRequest request);

    }
}
