using System.Collections.Generic;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.LiveConsultation
{
    public class AcceptLiveConsultationRequest : TokenRequest
    {    
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;           
    }

    public class AcceptLiveConsultationResult
    {        
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string UserCode { get; set; } = string.Empty;

        /// <summary>
        /// Room No. 
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }

        /// <summary>
        /// Sdk app id
        /// </summary>
        /// <value></value>
        public int AppId { get; set; }

        /// <summary>
        /// User sign for rtc
        /// </summary>
        /// <value>123456</value>
        public string UserSign { get; set; } = string.Empty;

        public IList<LiveConsultationMember> UserLiveDatas { get; set; }

        public IList<LiveConsultationMember> DeviceLiveDatas { get; set; }
    }

    public class AcceptLiveConsultationNotification
    {
        /// <summary>
        /// 通知类型枚举 接受会诊的通知
        /// </summary>
        /// <value>26</value>
        public NotificationTypeEnum NotificationType => NotificationTypeEnum.AcceptLiveConsultationNotification;
        
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
        
        /// <summary>
        /// The info of who accept the diagnosis metting invitation
        /// </summary>
        /// <value></value>
        public LiveConsultatioAccepterInfo Accepter {get;set;}
    }
}
