using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Enum;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 会诊过程中邀请他人请求
    /// </summary>
    public class InviteInLiveConsultationRequest : TokenRequest
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
        /// <summary>
        /// 用户或者设备编码集合
        /// </summary>
        /// <value></value>
        public IList<string> InviteCodes { get; set; }

        /// <summary>
        ///房间号码
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }
    }

    /// <summary>
    /// 会诊过程中邀请他人请求结果
    /// </summary>
    public class InviteInLiveConsultationResult
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

    }

    /// <summary>
    /// 会诊过程中邀请他人的通知
    /// </summary>
    public class InviteInLiveConsultationNotification
    {
        /// <summary>
        /// 通知类型枚举 会诊过程中邀请成员的通知
        /// </summary>
        /// <value>1</value>
        public NotificationTypeEnum NotificationType => NotificationTypeEnum.InviteInLiveConsultationNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// Room integer No 
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }

        /// <summary>
        /// The diagonosis meeting initiator
        /// </summary>
        /// <value></value>
        public LiveConsultationMember Initiator { get; set; }

        public IList<LiveConsultationMember> UserLiveData { get; set; }

        public IList<LiveConsultationMember> DeviceLiveData{ get; set; }
    }
}